==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/PlatformStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PlatformStatusFluent<A extends PlatformStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAlibabaCloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public AlibabaCloudPlatformStatus getAlibabaCloud();
  public AlibabaCloudPlatformStatus buildAlibabaCloud();
  public A withAlibabaCloud(AlibabaCloudPlatformStatus alibabaCloud);
  public Boolean hasAlibabaCloud();
  public PlatformStatusFluent.AlibabaCloudNested<A> withNewAlibabaCloud();
  public PlatformStatusFluent.AlibabaCloudNested<A> withNewAlibabaCloudLike(AlibabaCloudPlatformStatus item);
  public PlatformStatusFluent.AlibabaCloudNested<A> editAlibabaCloud();
  public PlatformStatusFluent.AlibabaCloudNested<A> editOrNewAlibabaCloud();
  public PlatformStatusFluent.AlibabaCloudNested<A> editOrNewAlibabaCloudLike(AlibabaCloudPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildAws instead.
   * @return The buildable object.
   */
  @Deprecated
  public AWSPlatformStatus getAws();
  public AWSPlatformStatus buildAws();
  public A withAws(AWSPlatformStatus aws);
  public Boolean hasAws();
  public PlatformStatusFluent.AwsNested<A> withNewAws();
  public PlatformStatusFluent.AwsNested<A> withNewAwsLike(AWSPlatformStatus item);
  public PlatformStatusFluent.AwsNested<A> editAws();
  public PlatformStatusFluent.AwsNested<A> editOrNewAws();
  public PlatformStatusFluent.AwsNested<A> editOrNewAwsLike(AWSPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildAzure instead.
   * @return The buildable object.
   */
  @Deprecated
  public AzurePlatformStatus getAzure();
  public AzurePlatformStatus buildAzure();
  public A withAzure(AzurePlatformStatus azure);
  public Boolean hasAzure();
  public A withNewAzure(String armEndpoint,String cloudName,String networkResourceGroupName,String resourceGroupName);
  public PlatformStatusFluent.AzureNested<A> withNewAzure();
  public PlatformStatusFluent.AzureNested<A> withNewAzureLike(AzurePlatformStatus item);
  public PlatformStatusFluent.AzureNested<A> editAzure();
  public PlatformStatusFluent.AzureNested<A> editOrNewAzure();
  public PlatformStatusFluent.AzureNested<A> editOrNewAzureLike(AzurePlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildBaremetal instead.
   * @return The buildable object.
   */
  @Deprecated
  public BareMetalPlatformStatus getBaremetal();
  public BareMetalPlatformStatus buildBaremetal();
  public A withBaremetal(BareMetalPlatformStatus baremetal);
  public Boolean hasBaremetal();
  public A withNewBaremetal(String apiServerInternalIP,String ingressIP,String nodeDNSIP);
  public PlatformStatusFluent.BaremetalNested<A> withNewBaremetal();
  public PlatformStatusFluent.BaremetalNested<A> withNewBaremetalLike(BareMetalPlatformStatus item);
  public PlatformStatusFluent.BaremetalNested<A> editBaremetal();
  public PlatformStatusFluent.BaremetalNested<A> editOrNewBaremetal();
  public PlatformStatusFluent.BaremetalNested<A> editOrNewBaremetalLike(BareMetalPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildEquinixMetal instead.
   * @return The buildable object.
   */
  @Deprecated
  public EquinixMetalPlatformStatus getEquinixMetal();
  public EquinixMetalPlatformStatus buildEquinixMetal();
  public A withEquinixMetal(EquinixMetalPlatformStatus equinixMetal);
  public Boolean hasEquinixMetal();
  public A withNewEquinixMetal(String apiServerInternalIP,String ingressIP);
  public PlatformStatusFluent.EquinixMetalNested<A> withNewEquinixMetal();
  public PlatformStatusFluent.EquinixMetalNested<A> withNewEquinixMetalLike(EquinixMetalPlatformStatus item);
  public PlatformStatusFluent.EquinixMetalNested<A> editEquinixMetal();
  public PlatformStatusFluent.EquinixMetalNested<A> editOrNewEquinixMetal();
  public PlatformStatusFluent.EquinixMetalNested<A> editOrNewEquinixMetalLike(EquinixMetalPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildGcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public GCPPlatformStatus getGcp();
  public GCPPlatformStatus buildGcp();
  public A withGcp(GCPPlatformStatus gcp);
  public Boolean hasGcp();
  public A withNewGcp(String projectID,String region);
  public PlatformStatusFluent.GcpNested<A> withNewGcp();
  public PlatformStatusFluent.GcpNested<A> withNewGcpLike(GCPPlatformStatus item);
  public PlatformStatusFluent.GcpNested<A> editGcp();
  public PlatformStatusFluent.GcpNested<A> editOrNewGcp();
  public PlatformStatusFluent.GcpNested<A> editOrNewGcpLike(GCPPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildIbmcloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public IBMCloudPlatformStatus getIbmcloud();
  public IBMCloudPlatformStatus buildIbmcloud();
  public A withIbmcloud(IBMCloudPlatformStatus ibmcloud);
  public Boolean hasIbmcloud();
  public A withNewIbmcloud(String cisInstanceCRN,String location,String providerType,String resourceGroupName);
  public PlatformStatusFluent.IbmcloudNested<A> withNewIbmcloud();
  public PlatformStatusFluent.IbmcloudNested<A> withNewIbmcloudLike(IBMCloudPlatformStatus item);
  public PlatformStatusFluent.IbmcloudNested<A> editIbmcloud();
  public PlatformStatusFluent.IbmcloudNested<A> editOrNewIbmcloud();
  public PlatformStatusFluent.IbmcloudNested<A> editOrNewIbmcloudLike(IBMCloudPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildKubevirt instead.
   * @return The buildable object.
   */
  @Deprecated
  public KubevirtPlatformStatus getKubevirt();
  public KubevirtPlatformStatus buildKubevirt();
  public A withKubevirt(KubevirtPlatformStatus kubevirt);
  public Boolean hasKubevirt();
  public A withNewKubevirt(String apiServerInternalIP,String ingressIP);
  public PlatformStatusFluent.KubevirtNested<A> withNewKubevirt();
  public PlatformStatusFluent.KubevirtNested<A> withNewKubevirtLike(KubevirtPlatformStatus item);
  public PlatformStatusFluent.KubevirtNested<A> editKubevirt();
  public PlatformStatusFluent.KubevirtNested<A> editOrNewKubevirt();
  public PlatformStatusFluent.KubevirtNested<A> editOrNewKubevirtLike(KubevirtPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildOpenstack instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenStackPlatformStatus getOpenstack();
  public OpenStackPlatformStatus buildOpenstack();
  public A withOpenstack(OpenStackPlatformStatus openstack);
  public Boolean hasOpenstack();
  public A withNewOpenstack(String apiServerInternalIP,String cloudName,String ingressIP,String nodeDNSIP);
  public PlatformStatusFluent.OpenstackNested<A> withNewOpenstack();
  public PlatformStatusFluent.OpenstackNested<A> withNewOpenstackLike(OpenStackPlatformStatus item);
  public PlatformStatusFluent.OpenstackNested<A> editOpenstack();
  public PlatformStatusFluent.OpenstackNested<A> editOrNewOpenstack();
  public PlatformStatusFluent.OpenstackNested<A> editOrNewOpenstackLike(OpenStackPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildOvirt instead.
   * @return The buildable object.
   */
  @Deprecated
  public OvirtPlatformStatus getOvirt();
  public OvirtPlatformStatus buildOvirt();
  public A withOvirt(OvirtPlatformStatus ovirt);
  public Boolean hasOvirt();
  public A withNewOvirt(String apiServerInternalIP,String ingressIP,String nodeDNSIP);
  public PlatformStatusFluent.OvirtNested<A> withNewOvirt();
  public PlatformStatusFluent.OvirtNested<A> withNewOvirtLike(OvirtPlatformStatus item);
  public PlatformStatusFluent.OvirtNested<A> editOvirt();
  public PlatformStatusFluent.OvirtNested<A> editOrNewOvirt();
  public PlatformStatusFluent.OvirtNested<A> editOrNewOvirtLike(OvirtPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildPowervs instead.
   * @return The buildable object.
   */
  @Deprecated
  public PowerVSPlatformStatus getPowervs();
  public PowerVSPlatformStatus buildPowervs();
  public A withPowervs(PowerVSPlatformStatus powervs);
  public Boolean hasPowervs();
  public PlatformStatusFluent.PowervsNested<A> withNewPowervs();
  public PlatformStatusFluent.PowervsNested<A> withNewPowervsLike(PowerVSPlatformStatus item);
  public PlatformStatusFluent.PowervsNested<A> editPowervs();
  public PlatformStatusFluent.PowervsNested<A> editOrNewPowervs();
  public PlatformStatusFluent.PowervsNested<A> editOrNewPowervsLike(PowerVSPlatformStatus item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  
  /**
   * This method has been deprecated, please use method buildVsphere instead.
   * @return The buildable object.
   */
  @Deprecated
  public VSpherePlatformStatus getVsphere();
  public VSpherePlatformStatus buildVsphere();
  public A withVsphere(VSpherePlatformStatus vsphere);
  public Boolean hasVsphere();
  public A withNewVsphere(String apiServerInternalIP,String ingressIP,String nodeDNSIP);
  public PlatformStatusFluent.VsphereNested<A> withNewVsphere();
  public PlatformStatusFluent.VsphereNested<A> withNewVsphereLike(VSpherePlatformStatus item);
  public PlatformStatusFluent.VsphereNested<A> editVsphere();
  public PlatformStatusFluent.VsphereNested<A> editOrNewVsphere();
  public PlatformStatusFluent.VsphereNested<A> editOrNewVsphereLike(VSpherePlatformStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AlibabaCloudNested<N> extends Nested<N>,AlibabaCloudPlatformStatusFluent<PlatformStatusFluent.AlibabaCloudNested<N>>{
    public N and();
    public N endAlibabaCloud();
    
  }
  public interface AwsNested<N> extends Nested<N>,AWSPlatformStatusFluent<PlatformStatusFluent.AwsNested<N>>{
    public N and();
    public N endAws();
    
  }
  public interface AzureNested<N> extends Nested<N>,AzurePlatformStatusFluent<PlatformStatusFluent.AzureNested<N>>{
    public N and();
    public N endAzure();
    
  }
  public interface BaremetalNested<N> extends Nested<N>,BareMetalPlatformStatusFluent<PlatformStatusFluent.BaremetalNested<N>>{
    public N and();
    public N endBaremetal();
    
  }
  public interface EquinixMetalNested<N> extends Nested<N>,EquinixMetalPlatformStatusFluent<PlatformStatusFluent.EquinixMetalNested<N>>{
    public N and();
    public N endEquinixMetal();
    
  }
  public interface GcpNested<N> extends Nested<N>,GCPPlatformStatusFluent<PlatformStatusFluent.GcpNested<N>>{
    public N and();
    public N endGcp();
    
  }
  public interface IbmcloudNested<N> extends Nested<N>,IBMCloudPlatformStatusFluent<PlatformStatusFluent.IbmcloudNested<N>>{
    public N and();
    public N endIbmcloud();
    
  }
  public interface KubevirtNested<N> extends Nested<N>,KubevirtPlatformStatusFluent<PlatformStatusFluent.KubevirtNested<N>>{
    public N and();
    public N endKubevirt();
    
  }
  public interface OpenstackNested<N> extends Nested<N>,OpenStackPlatformStatusFluent<PlatformStatusFluent.OpenstackNested<N>>{
    public N and();
    public N endOpenstack();
    
  }
  public interface OvirtNested<N> extends Nested<N>,OvirtPlatformStatusFluent<PlatformStatusFluent.OvirtNested<N>>{
    public N and();
    public N endOvirt();
    
  }
  public interface PowervsNested<N> extends Nested<N>,PowerVSPlatformStatusFluent<PlatformStatusFluent.PowervsNested<N>>{
    public N and();
    public N endPowervs();
    
  }
  public interface VsphereNested<N> extends Nested<N>,VSpherePlatformStatusFluent<PlatformStatusFluent.VsphereNested<N>>{
    public N and();
    public N endVsphere();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/PlatformStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PlatformStatusFluent<A extends PlatformStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAlibabaCloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public AlibabaCloudPlatformStatus getAlibabaCloud();
  public AlibabaCloudPlatformStatus buildAlibabaCloud();
  public A withAlibabaCloud(AlibabaCloudPlatformStatus alibabaCloud);
  public Boolean hasAlibabaCloud();
  public PlatformStatusFluent.AlibabaCloudNested<A> withNewAlibabaCloud();
  public PlatformStatusFluent.AlibabaCloudNested<A> withNewAlibabaCloudLike(AlibabaCloudPlatformStatus item);
  public PlatformStatusFluent.AlibabaCloudNested<A> editAlibabaCloud();
  public PlatformStatusFluent.AlibabaCloudNested<A> editOrNewAlibabaCloud();
  public PlatformStatusFluent.AlibabaCloudNested<A> editOrNewAlibabaCloudLike(AlibabaCloudPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildAws instead.
   * @return The buildable object.
   */
  @Deprecated
  public AWSPlatformStatus getAws();
  public AWSPlatformStatus buildAws();
  public A withAws(AWSPlatformStatus aws);
  public Boolean hasAws();
  public PlatformStatusFluent.AwsNested<A> withNewAws();
  public PlatformStatusFluent.AwsNested<A> withNewAwsLike(AWSPlatformStatus item);
  public PlatformStatusFluent.AwsNested<A> editAws();
  public PlatformStatusFluent.AwsNested<A> editOrNewAws();
  public PlatformStatusFluent.AwsNested<A> editOrNewAwsLike(AWSPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildAzure instead.
   * @return The buildable object.
   */
  @Deprecated
  public AzurePlatformStatus getAzure();
  public AzurePlatformStatus buildAzure();
  public A withAzure(AzurePlatformStatus azure);
  public Boolean hasAzure();
  public A withNewAzure(String armEndpoint,String cloudName,String networkResourceGroupName,String resourceGroupName);
  public PlatformStatusFluent.AzureNested<A> withNewAzure();
  public PlatformStatusFluent.AzureNested<A> withNewAzureLike(AzurePlatformStatus item);
  public PlatformStatusFluent.AzureNested<A> editAzure();
  public PlatformStatusFluent.AzureNested<A> editOrNewAzure();
  public PlatformStatusFluent.AzureNested<A> editOrNewAzureLike(AzurePlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildBaremetal instead.
   * @return The buildable object.
   */
  @Deprecated
  public BareMetalPlatformStatus getBaremetal();
  public BareMetalPlatformStatus buildBaremetal();
  public A withBaremetal(BareMetalPlatformStatus baremetal);
  public Boolean hasBaremetal();
  public A withNewBaremetal(String apiServerInternalIP,String ingressIP,String nodeDNSIP);
  public PlatformStatusFluent.BaremetalNested<A> withNewBaremetal();
  public PlatformStatusFluent.BaremetalNested<A> withNewBaremetalLike(BareMetalPlatformStatus item);
  public PlatformStatusFluent.BaremetalNested<A> editBaremetal();
  public PlatformStatusFluent.BaremetalNested<A> editOrNewBaremetal();
  public PlatformStatusFluent.BaremetalNested<A> editOrNewBaremetalLike(BareMetalPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildEquinixMetal instead.
   * @return The buildable object.
   */
  @Deprecated
  public EquinixMetalPlatformStatus getEquinixMetal();
  public EquinixMetalPlatformStatus buildEquinixMetal();
  public A withEquinixMetal(EquinixMetalPlatformStatus equinixMetal);
  public Boolean hasEquinixMetal();
  public A withNewEquinixMetal(String apiServerInternalIP,String ingressIP);
  public PlatformStatusFluent.EquinixMetalNested<A> withNewEquinixMetal();
  public PlatformStatusFluent.EquinixMetalNested<A> withNewEquinixMetalLike(EquinixMetalPlatformStatus item);
  public PlatformStatusFluent.EquinixMetalNested<A> editEquinixMetal();
  public PlatformStatusFluent.EquinixMetalNested<A> editOrNewEquinixMetal();
  public PlatformStatusFluent.EquinixMetalNested<A> editOrNewEquinixMetalLike(EquinixMetalPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildGcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public GCPPlatformStatus getGcp();
  public GCPPlatformStatus buildGcp();
  public A withGcp(GCPPlatformStatus gcp);
  public Boolean hasGcp();
  public A withNewGcp(String projectID,String region);
  public PlatformStatusFluent.GcpNested<A> withNewGcp();
  public PlatformStatusFluent.GcpNested<A> withNewGcpLike(GCPPlatformStatus item);
  public PlatformStatusFluent.GcpNested<A> editGcp();
  public PlatformStatusFluent.GcpNested<A> editOrNewGcp();
  public PlatformStatusFluent.GcpNested<A> editOrNewGcpLike(GCPPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildIbmcloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public IBMCloudPlatformStatus getIbmcloud();
  public IBMCloudPlatformStatus buildIbmcloud();
  public A withIbmcloud(IBMCloudPlatformStatus ibmcloud);
  public Boolean hasIbmcloud();
  public A withNewIbmcloud(String cisInstanceCRN,String location,String providerType,String resourceGroupName);
  public PlatformStatusFluent.IbmcloudNested<A> withNewIbmcloud();
  public PlatformStatusFluent.IbmcloudNested<A> withNewIbmcloudLike(IBMCloudPlatformStatus item);
  public PlatformStatusFluent.IbmcloudNested<A> editIbmcloud();
  public PlatformStatusFluent.IbmcloudNested<A> editOrNewIbmcloud();
  public PlatformStatusFluent.IbmcloudNested<A> editOrNewIbmcloudLike(IBMCloudPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildKubevirt instead.
   * @return The buildable object.
   */
  @Deprecated
  public KubevirtPlatformStatus getKubevirt();
  public KubevirtPlatformStatus buildKubevirt();
  public A withKubevirt(KubevirtPlatformStatus kubevirt);
  public Boolean hasKubevirt();
  public A withNewKubevirt(String apiServerInternalIP,String ingressIP);
  public PlatformStatusFluent.KubevirtNested<A> withNewKubevirt();
  public PlatformStatusFluent.KubevirtNested<A> withNewKubevirtLike(KubevirtPlatformStatus item);
  public PlatformStatusFluent.KubevirtNested<A> editKubevirt();
  public PlatformStatusFluent.KubevirtNested<A> editOrNewKubevirt();
  public PlatformStatusFluent.KubevirtNested<A> editOrNewKubevirtLike(KubevirtPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildOpenstack instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenStackPlatformStatus getOpenstack();
  public OpenStackPlatformStatus buildOpenstack();
  public A withOpenstack(OpenStackPlatformStatus openstack);
  public Boolean hasOpenstack();
  public A withNewOpenstack(String apiServerInternalIP,String cloudName,String ingressIP,String nodeDNSIP);
  public PlatformStatusFluent.OpenstackNested<A> withNewOpenstack();
  public PlatformStatusFluent.OpenstackNested<A> withNewOpenstackLike(OpenStackPlatformStatus item);
  public PlatformStatusFluent.OpenstackNested<A> editOpenstack();
  public PlatformStatusFluent.OpenstackNested<A> editOrNewOpenstack();
  public PlatformStatusFluent.OpenstackNested<A> editOrNewOpenstackLike(OpenStackPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildOvirt instead.
   * @return The buildable object.
   */
  @Deprecated
  public OvirtPlatformStatus getOvirt();
  public OvirtPlatformStatus buildOvirt();
  public A withOvirt(OvirtPlatformStatus ovirt);
  public Boolean hasOvirt();
  public A withNewOvirt(String apiServerInternalIP,String ingressIP,String nodeDNSIP);
  public PlatformStatusFluent.OvirtNested<A> withNewOvirt();
  public PlatformStatusFluent.OvirtNested<A> withNewOvirtLike(OvirtPlatformStatus item);
  public PlatformStatusFluent.OvirtNested<A> editOvirt();
  public PlatformStatusFluent.OvirtNested<A> editOrNewOvirt();
  public PlatformStatusFluent.OvirtNested<A> editOrNewOvirtLike(OvirtPlatformStatus item);
  
  /**
   * This method has been deprecated, please use method buildPowervs instead.
   * @return The buildable object.
   */
  @Deprecated
  public PowerVSPlatformStatus getPowervs();
  public PowerVSPlatformStatus buildPowervs();
  public A withPowervs(PowerVSPlatformStatus powervs);
  public Boolean hasPowervs();
  public PlatformStatusFluent.PowervsNested<A> withNewPowervs();
  public PlatformStatusFluent.PowervsNested<A> withNewPowervsLike(PowerVSPlatformStatus item);
  public PlatformStatusFluent.PowervsNested<A> editPowervs();
  public PlatformStatusFluent.PowervsNested<A> editOrNewPowervs();
  public PlatformStatusFluent.PowervsNested<A> editOrNewPowervsLike(PowerVSPlatformStatus item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  
  /**
   * This method has been deprecated, please use method buildVsphere instead.
   * @return The buildable object.
   */
  @Deprecated
  public VSpherePlatformStatus getVsphere();
  public VSpherePlatformStatus buildVsphere();
  public A withVsphere(VSpherePlatformStatus vsphere);
  public Boolean hasVsphere();
  public A withNewVsphere(String apiServerInternalIP,String ingressIP,String nodeDNSIP);
  public PlatformStatusFluent.VsphereNested<A> withNewVsphere();
  public PlatformStatusFluent.VsphereNested<A> withNewVsphereLike(VSpherePlatformStatus item);
  public PlatformStatusFluent.VsphereNested<A> editVsphere();
  public PlatformStatusFluent.VsphereNested<A> editOrNewVsphere();
  public PlatformStatusFluent.VsphereNested<A> editOrNewVsphereLike(VSpherePlatformStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AlibabaCloudNested<N> extends Nested<N>,AlibabaCloudPlatformStatusFluent<PlatformStatusFluent.AlibabaCloudNested<N>>{
    public N and();
    public N endAlibabaCloud();
    
  }
  public interface AwsNested<N> extends Nested<N>,AWSPlatformStatusFluent<PlatformStatusFluent.AwsNested<N>>{
    public N and();
    public N endAws();
    
  }
  public interface AzureNested<N> extends Nested<N>,AzurePlatformStatusFluent<PlatformStatusFluent.AzureNested<N>>{
    public N and();
    public N endAzure();
    
  }
  public interface BaremetalNested<N> extends Nested<N>,BareMetalPlatformStatusFluent<PlatformStatusFluent.BaremetalNested<N>>{
    public N and();
    public N endBaremetal();
    
  }
  public interface EquinixMetalNested<N> extends Nested<N>,EquinixMetalPlatformStatusFluent<PlatformStatusFluent.EquinixMetalNested<N>>{
    public N and();
    public N endEquinixMetal();
    
  }
  public interface GcpNested<N> extends Nested<N>,GCPPlatformStatusFluent<PlatformStatusFluent.GcpNested<N>>{
    public N and();
    public N endGcp();
    
  }
  public interface IbmcloudNested<N> extends Nested<N>,IBMCloudPlatformStatusFluent<PlatformStatusFluent.IbmcloudNested<N>>{
    public N and();
    public N endIbmcloud();
    
  }
  public interface KubevirtNested<N> extends Nested<N>,KubevirtPlatformStatusFluent<PlatformStatusFluent.KubevirtNested<N>>{
    public N and();
    public N endKubevirt();
    
  }
  public interface OpenstackNested<N> extends Nested<N>,OpenStackPlatformStatusFluent<PlatformStatusFluent.OpenstackNested<N>>{
    public N and();
    public N endOpenstack();
    
  }
  public interface OvirtNested<N> extends Nested<N>,OvirtPlatformStatusFluent<PlatformStatusFluent.OvirtNested<N>>{
    public N and();
    public N endOvirt();
    
  }
  public interface PowervsNested<N> extends Nested<N>,PowerVSPlatformStatusFluent<PlatformStatusFluent.PowervsNested<N>>{
    public N and();
    public N endPowervs();
    
  }
  public interface VsphereNested<N> extends Nested<N>,VSpherePlatformStatusFluent<PlatformStatusFluent.VsphereNested<N>>{
    public N and();
    public N endVsphere();
    
  }
  
}
